@@ -1,8 +1,10 @@
 use super::compute_oflags;
 use crate::fs::{stat_unchecked, OpenOptions, OpenUncheckedError};
 use io_lifetimes::FromFd;
-use posish::fs::{openat, Mode};
-use posish::io::Errno;
+use posish::{
+    fs::{openat, Mode},
+    io,
+};
 use std::{fs, path::Path};
 #[cfg(any(target_os = "android", target_os = "linux"))]
 use {crate::fs::ensure_cloexec, io_lifetimes::AsFd};
@@ -27,32 +29,32 @@ pub(crate) fn open_unchecked(
         }
         Err(err) => err,
     };
-    match Errno::from_io_error(&err) {
+    match err {
         // `ELOOP` is the POSIX standard and most widely used error code to
         // indicate that a symlink was found when `O_NOFOLLOW` was set.
         #[cfg(not(any(target_os = "freebsd", target_os = "dragonfly", target_os = "netbsd")))]
-        Some(Errno::LOOP) => Err(OpenUncheckedError::Symlink(err, ())),
+        io::Error::LOOP => Err(OpenUncheckedError::Symlink(err.into(), ())),
 
         // FreeBSD and similar (but not Darwin) use `EMLINK`.
         #[cfg(any(target_os = "freebsd", target_os = "dragonfly"))]
-        Some(Errno::MLINK) => Err(OpenUncheckedError::Symlink(err, ())),
+        io::Error::MLINK => Err(OpenUncheckedError::Symlink(err.into(), ())),
 
         // NetBSD uses `EFTYPE`.
         #[cfg(any(target_os = "netbsd"))]
-        Some(Errno::FTYPE) => Err(OpenUncheckedError::Symlink(err, ())),
+        io::Error::FTYPE => Err(OpenUncheckedError::Symlink(err.into(), ())),
 
-        Some(Errno::NOENT) => Err(OpenUncheckedError::NotFound(err)),
-        Some(Errno::NOTDIR) => {
+        io::Error::NOENT => Err(OpenUncheckedError::NotFound(err.into())),
+        io::Error::NOTDIR => {
             if options.dir_required
                 && stat_unchecked(start, path, options.follow)
                     .map(|m| m.file_type().is_symlink())
                     .unwrap_or(false)
             {
-                Err(OpenUncheckedError::Symlink(err, ()))
+                Err(OpenUncheckedError::Symlink(err.into(), ()))
             } else {
-                Err(OpenUncheckedError::NotFound(err))
+                Err(OpenUncheckedError::NotFound(err.into()))
             }
         }
-        _ => Err(OpenUncheckedError::Other(err)),
+        _ => Err(OpenUncheckedError::Other(err.into())),
     }
 }
