@@ -4,5 +4,5 @@ use std::{fs, io, path::Path};
 /// *Unsandboxed* function similar to `remove_dir`, but which does not perform
 /// sandboxing.
 pub(crate) fn remove_dir_unchecked(start: &fs::File, path: &Path) -> io::Result<()> {
-    unlinkat(start, path, AtFlags::REMOVEDIR)
+    Ok(unlinkat(start, path, AtFlags::REMOVEDIR)?)
 }
