@@ -12,8 +12,7 @@ use super::super::super::fs::{c_str, compute_oflags};
 use crate::fs::is_same_file;
 use crate::fs::{errors, manually, OpenOptions};
 use io_lifetimes::FromFd;
-use posish::fs::{openat2, Mode, OFlags, ResolveFlags};
-use posish::io::Errno;
+use posish::fs::{openat2, Mode, OFlags, RawMode, ResolveFlags};
 use std::{
     fs, io,
     path::Path,
@@ -30,7 +29,7 @@ pub(crate) fn open_impl(
 
     // If that returned `ENOSYS`, use a fallback strategy.
     if let Err(err) = &result {
-        if let Some(Errno::NOSYS) = Errno::from_io_error(err) {
+        if Some(posish::io::Error::NOSYS.raw_os_error()) == err.raw_os_error() {
             return manually::open(start, path, options);
         }
     }
@@ -53,7 +52,7 @@ pub(crate) fn open_beneath(
         // Do two `contains` checks because `TMPFILE` may be represented with
         // multiple flags and we need to ensure they're all set.
         let mode = if oflags.contains(OFlags::CREATE) || oflags.contains(OFlags::TMPFILE) {
-            Mode::from_bits(options.ext.mode & 0o7777).unwrap()
+            Mode::from_bits((options.ext.mode & 0o7777) as RawMode).unwrap()
         } else {
             Mode::empty()
         };
@@ -85,9 +84,9 @@ pub(crate) fn open_beneath(
 
                     return Ok(file);
                 }
-                Err(err) => match Errno::from_io_error(&err) {
-                    Some(Errno::AGAIN) => continue,
-                    Some(Errno::XDEV) => return Err(errors::escape_attempt()),
+                Err(err) => match err {
+                    posish::io::Error::AGAIN => continue,
+                    posish::io::Error::XDEV => return Err(errors::escape_attempt()),
 
                     // `EPERM` is used by some `seccomp` sandboxes to indicate
                     // that `openat2` is unimplemented:
@@ -97,23 +96,23 @@ pub(crate) fn open_beneath(
                     // or a file seal prevented the operation, and it's complex
                     // to detect those cases, so exit the loop and use the
                     // fallback.
-                    Some(Errno::PERM) => break,
+                    posish::io::Error::PERM => break,
 
                     // `ENOSYS` means `openat2` is permanently unavailable;
                     // mark it so and exit the loop.
-                    Some(Errno::NOSYS) => {
+                    posish::io::Error::NOSYS => {
                         INVALID.store(true, Relaxed);
                         break;
                     }
 
-                    _ => return Err(err),
+                    _ => return Err(err.into()),
                 },
             }
         }
     }
 
     // `openat2` is unavailable, either temporarily or permanently.
-    Err(Errno::NOSYS.io_error())
+    Err(posish::io::Error::NOSYS.into())
 }
 
 #[cfg(racy_asserts)]
